@@ -2,25 +2,17 @@
 from __future__ import absolute_import
 
 import os
-import six
+import subprocess
 import sys
-from pipes import quote
+import yaml
 
 from django.conf import settings as django_settings
 from django.template import loader, Context
 
 import click
 
-import yurl
-
 from aldryn_addons.utils import openfile, boolean_ish
 
-if six.PY2:
-    # backport of python3 subprocess with timeout support
-    import subprocess32 as subprocess
-else:
-    import subprocess
-
 
 # add the current directory to pythonpath. So the project files can be read.
 BASE_DIR = os.getcwd()
@@ -34,14 +26,24 @@ def web(ctx_obj):
     launch the webserver of choice (uwsgi)
     """
     if any(boolean_ish(ctx_obj['settings'][key]) for key in
-           ('ENABLE_NGINX', 'ENABLE_PAGESPEED')):
-        # uwsgi behind nginx. possibly with pagespeed
+           ('ENABLE_NGINX', 'ENABLE_PAGESPEED', 'ENABLE_BROWSERCACHE')):
+        # uwsgi behind nginx. possibly with pagespeed/browsercache
         start_with_nginx(ctx_obj['settings'])
     else:
         # pure uwsgi
         execute(start_uwsgi_command(settings=ctx_obj['settings'], port=80))
 
 
+@click.command()
+@click.pass_obj
+def worker(ctx_obj):
+    """
+    coming soon: launch the background worker
+    """
+    # TODO: celery worker startup, once available
+    pass
+
+
 @click.command()
 @click.pass_obj
 def migrate(ctx_obj):
@@ -82,6 +84,7 @@ def main(ctx, verbose):
 
 
 main.add_command(web)
+main.add_command(worker)
 main.add_command(migrate)
 
 
@@ -109,27 +112,8 @@ def execute(args, script=None):
     os.execvpe(command, args, get_env())
 
 
-def get_static_serving_args(base_url, root, header_patterns):
-    base_path = yurl.URL(base_url).path.lstrip('/')
-
-    args = [
-        '--static-map=/{}={}'.format(base_path, root),
-        '--route={} addheader:Vary: Accept-Encoding'.format(
-            os.path.join('^', base_path, '.*'),
-        ),
-    ]
-
-    for pattern, headers in header_patterns:
-        pattern = os.path.join('^', base_path, pattern)
-        for k, v in headers.items():
-            args.append('--route={} addheader:{}: {}'.format(pattern, k, v))
-        args.append('--route={} last:'.format(pattern, k, v))
-
-    return args
-
-
 def start_uwsgi_command(settings, port=None):
-    cmd = [
+    return [
         'uwsgi',
         '--module=wsgi',
         '--http=0.0.0.0:{}'.format(port or settings.get('PORT')),
@@ -137,46 +121,9 @@ def start_uwsgi_command(settings, port=None):
         '--workers={}'.format(settings['DJANGO_WEB_WORKERS']),
         '--max-requests={}'.format(settings['DJANGO_WEB_MAX_REQUESTS']),
         '--harakiri={}'.format(settings['DJANGO_WEB_TIMEOUT']),
-        '--lazy-apps',
-        '--honour-range',
+        # '--honour-stdin',
     ]
 
-    serve_static = False
-
-    if not settings['ENABLE_SYNCING']:
-        if not settings['STATIC_URL_IS_ON_OTHER_DOMAIN']:
-            serve_static = True
-            cmd.extend(get_static_serving_args(
-                settings['STATIC_URL'],
-                settings['STATIC_ROOT'],
-                settings['STATIC_HEADERS'],
-            ))
-
-        if not settings['MEDIA_URL_IS_ON_OTHER_DOMAIN']:
-            serve_static = True
-            cmd.extend(get_static_serving_args(
-                settings['MEDIA_URL'],
-                settings['MEDIA_ROOT'],
-                settings['MEDIA_HEADERS'],
-            ))
-
-        if serve_static:
-            cmd.extend([
-                # Start 2 offloading threads for each worker
-                '--offload-threads=2',
-
-                # Cache resolved paths for up to 1 day (limited to 5k entries
-                # of max 1kB size each)
-                '--static-cache-paths=86400',
-                '--static-cache-paths-name=staticpaths',
-                '--cache2=name=staticpaths,items=5000,blocksize=1k,purge_lru,ignore_full',
-
-                # Serve .gz files if that version is available
-                '--static-gzip-all',
-            ])
-
-    return cmd
-
 
 def start_procfile_command(procfile_path):
     return [
@@ -196,16 +143,14 @@ def start_with_nginx(settings):
         raise click.UsageError(
             'NGINX_CONF_PATH and NGINX_PROCFILE_PATH must be configured'
         )
-
-    commands = {
-        'nginx': 'nginx',
-        'django': ' '.join(quote(c) for c in start_uwsgi_command(
-            settings, port=settings['BACKEND_PORT']))
-    }
-
-    procfile = '\n'.join(
-        '{}: {}'.format(name, command)
-        for name, command in commands.items()
+    procfile = yaml.safe_dump(
+        {
+            'nginx': 'nginx',
+            'django': ' '.join(
+                start_uwsgi_command(settings, port=settings['BACKEND_PORT'])
+            )
+        },
+        default_flow_style=False,
     )
 
     if (
