@@ -1,9 +1,9 @@
-# -*- coding: utf-8 -*-
 import os
-import sys
-from getenv import env
+
 import django.core.management
 
+from getenv import env
+
 
 def manage(path):
     _setup(path=path)
@@ -24,5 +24,13 @@ def wsgi(path):
     return app
 
 
+def setup(path):
+    _setup(path)
+    import django
+    django.setup()
+
+
 def _setup(path):
-    os.environ['DJANGO_SETTINGS_MODULE'] = env('DJANGO_SETTINGS_MODULE', 'settings')
+    os.environ['DJANGO_SETTINGS_MODULE'] = env(
+        'DJANGO_SETTINGS_MODULE', 'settings'
+    )
